@@ -6,18 +6,18 @@ Linux system logs, and other log types to identify security threats and stores t
 as structured data in Elasticsearch for visualization and analysis.
 """
 
-__version__ = "0.0.0"
+__version__ = "1.0.5"
 __author__ = "JungJungIn"
 __email__ = "call518@gmail.com"
 
 # Import main functionality
 from .core.commons import (
     initialize_llm_model,
-    get_analysis_config,
     process_log_chunk,
     run_generic_batch_analysis,
     run_generic_realtime_analysis
 )
+from .core.config import get_analysis_config
 
 from .utils.geoip_downloader import download_geoip_database
 
