@@ -2,19 +2,16 @@
 
 This package contains specialized log analyzers for different log types:
 - httpd_access: HTTP access log analyzer
-- httpd_apache: Apache error log analyzer  
+- httpd_server: HTTP server error log analyzer  
 - linux_system: Linux system log analyzer
-- tcpdump_packet: TCP dump packet analyzer
 """
 
 from .httpd_access import LogAnalysis as HTTPDAccessAnalysis
-from .httpd_apache import LogAnalysis as HTTPDApacheAnalysis
+from .httpd_server import LogAnalysis as HTTPDServerAnalysis
 from .linux_system import LogAnalysis as LinuxSystemAnalysis
-from .tcpdump_packet import PacketAnalysis as TCPDumpAnalysis
 
 __all__ = [
     'HTTPDAccessAnalysis',
-    'HTTPDApacheAnalysis', 
-    'LinuxSystemAnalysis',
-    'TCPDumpAnalysis'
+    'HTTPDServerAnalysis', 
+    'LinuxSystemAnalysis'
 ]
