@@ -11,9 +11,9 @@ import argparse
 from typing import Optional
 
 # Logging setup
-from logsentinelai.core.commons import setup_logger, LOG_LEVEL
+from logsentinelai.core.commons import setup_logger
 
-logger = setup_logger("logsentinelai.cli", LOG_LEVEL)
+logger = setup_logger("logsentinelai.cli")
 
 def main() -> None:
     """Main CLI entry point"""
@@ -58,7 +58,7 @@ For detailed help on each command, use: <command> --help
         action="version", 
         version="LogSentinelAI v0.1.0"
     )
-    
+
     subparsers = parser.add_subparsers(
         dest="command",
         help="Available analysis commands",
